@@ -1,10 +1,26 @@
-#' Internal Logic Forest Functions
+#' Truth table
 #'
-#' This function is called by \code{prime.imp}. It is not intended to be used independently of this function.
+#' Internal function to evaluate importance of predictor combinations
+#' @importFrom LogicReg eval.logreg logreg logreg.anneal.control
+#' @importFrom methods is
+#'
+#' @param data Input data.
+#' @param tree Logic tree constructed for a sample.
+#' @param Xs Input predictors.
+#' @param mtype Model type: classification or linear or survival regression.
+
+#' @details
+#' Creates a matrix of all interactions contained in one sample's logic tree.
+#'
+#' @return \code{mat.truth}: Matrix of all interactions contained in one sample's logic tree
+#'
+#' @references
+#' Wolf BJ, Hill EG, Slate EH. Logic Forest: an ensemble classifier for discovering logical combinations of binary markers. Bioinformatics. 2010;26(17):2183-2189. doi:10.1093/bioinformatics/btq354
+#'
+#' @author Bethany J. Wolf \email{wolfb@@musc.edu}
+#'
+#' @seealso \code{\link{prime.imp}}
 #'
-#' Generates a matrix of binary predictor values corresponding to a prediction of one for a specific logic regression tree within a logic forest. Only those predictors included in the logic regression tree are included in the matrix.
-#' @returns No return value, called for side effects
-#' @export
 #' @keywords internal
 
 TTab<-function(data, tree, Xs, mtype)
@@ -30,6 +46,8 @@ TTab<-function(data, tree, Xs, mtype)
   mat.truth<-cbind(mat.perms, outcome=pred.out)
   if(mtype==1) {truth<-ifelse(tree$coef>0 | is.na(tree$coef),1,0)}
   if(mtype==2) {truth<-1}
+  if(mtype==3) {truth<-1}
+  if(mtype==4) {truth<-1}
   ids.truth<-mat.truth[,"outcome"]==truth
   mat.truth<-mat.truth[ids.truth,-ncol(mat.truth),drop=FALSE]
   mat.truth
