@@ -1,21 +1,26 @@
 #' Internal Logic Forest Functions
 #'
-#' This function is called by \code{pimp.import} and \code{LBoost.PIs}. It is not intended to be used independently of these functions.
-#' @returns No return value, called for side effects
-#' @details
-#' It generates a list of all variables and variable interactions identified by a specific logic regression tree with in a logic forest model or and LBoost model.
+#' This function is called by \code{pimp.import}. It is not intended to be used independently of these functions.
+#' @param tree An object of class \code{"logregtree"}
+#' @param data Data used to fit the logforest
+#' @param Xs Predictors
+#' @param mtype Model type
 #'
+#' @returns ListPI An object of class \code{"primeImp"} containing all variables and variable interactions
 #'
 #' @export
 #' @keywords internal
+#'
 
 prime.imp<-function (tree, data, Xs, mtype)
 {
+  test.mat <- NULL  # Initialize to avoid 'no visible binding' note
   mat<-TTab(data, tree, Xs=Xs, mtype=mtype)
+  test.mat <<- mat
+
   mat[mat == 0] <- -1
   n.var <- ncol(mat)
-  if (is.null(colnames(mat)))
-    colnames(mat) <- paste("X", 1:n.var, sep = "")
+  if (is.null(colnames(mat))) {colnames(mat) <- paste("X", 1:n.var, sep = "")}
   ia <- p.combos(n.var)
   ia.rowS <- rowSums(ia)
   vec.primes <- character(0)
@@ -27,7 +32,8 @@ prime.imp<-function (tree, data, Xs, mtype)
     x <- x[x != ""]
     paste(x, collapse = " & ")
   }
-  tmp.list<-vector("list",n.var)
+  tmp.list <- vector("list",n.var)
+
   for (i in 1:n.var)
   {
     pairt <- p.combos(i, conj = -1)
@@ -35,13 +41,7 @@ prime.imp<-function (tree, data, Xs, mtype)
     ia2 <- matrix(ia[ia.rowS == i, ], ncol = n.var)
     tmp <- matrix(0, nrow(ia2) * n.p, n.var)
     for (j in 1:nrow(ia2)) tmp[((j - 1) * n.p + 1):(j * n.p), ia2[j, ] == 1] <- pairt
-    if (length(vec.primes) > 0) {
-      tmp9 <- tmp %*% t(mat.in)
-      tmp10 <- diag(mat.in %*% t(mat.in))
-      tmp11 <- t(tmp10) %x% rep(1, nrow(tmp)) == tmp9
-      tmp.in <- which(rowSums(tmp11) == 0)
-      tmp <- tmp[tmp.in, ]
-    }
+
     tmp2 <- tmp %*% t(mat) == i
     ids <- which(rowSums(tmp2) == 2^(n.var - i))
     tmp <- tmp[ids, ]
@@ -72,6 +72,7 @@ prime.imp<-function (tree, data, Xs, mtype)
   }
   vec.pimpvars<-sort(unique(unlist(list.pimps)))
   n.prime <- length(vec.primes)
+
   listPI <- list(vec.primes=vec.primes, tmp.mat=tmp.mat, vec.pimpvars=vec.pimpvars, list.pimps=list.pimps)
   class(listPI) <- "primeImp"
   listPI
