@@ -1,11 +1,20 @@
+#' Print method for logic forest predictions
+#'
+#' Displays the results of a prediction from a logic forest model.
+#'
+#' @param x An object of class \code{"LFprediction"}.
+#' @param ... Additional arguments (currently ignored).
+#'
+#' @return No return value. This function is called for its side effects (printing).
+#'
 #' @export
 
 print.LFprediction<-function(x, ...)
 {
-  if(!is(x,"LFprediction"))
+  if(inherits(x)!="LFprediction")
     stop("x not of class LFprediction")
   prdct<-x$LFprediction
-  if(x$model.type=="Classification")
+  if(model.type=="Classification")
   {
     prop<-x$proportion_one
 
@@ -31,7 +40,7 @@ print.LFprediction<-function(x, ...)
     }
   }
 
-  if(x$model.type=="Linear Regression")
+  if(model.type=="Linear Regression")
   {
     if(length(x)==4)
     {
@@ -51,4 +60,3 @@ print.LFprediction<-function(x, ...)
     }
   }
 }
-
