@@ -1,15 +1,36 @@
+#' Print method for logic forest models
+#'
+#' Prints the important predictors from a fitted logic forest model.
+#'
+#' @param x An object of class \code{"logforest"}.
+#' @param sortby A character string specifying whether to sort the predictors by \code{"importance"} (default) or \code{"frequency"}.
+#' @param ... Additional arguments (currently ignored).
+#'
+#' @return No return value. This function is called for its side effects (printing).
+#'
 #' @export
-
-print.logforest<-function(x, ...)
+print.logforest<-function(x, sortby = 'importance', ...)
 {
-  if (!is(x,"logforest"))
+  if (inherits(x)!= "logforest")
     stop("n not of class logforest")
   num<-x$numout
   OOBerr<-x$OOBmiss
-  pscore<-sort(x$Predictor.importance, decreasing=TRUE)
-  pred.freq<-x$Predictor.frequency[names(pscore)[1:num]]
-  piscore<-sort(x$PI.importance, decreasing=TRUE)
-  vimp.freq<-x$PI.frequency[names(piscore)[1:num]]
+
+  #MN added if statements to work with sortby option
+  if (sortby == 'frequency') {
+    pscore<-x$Predictor.importance
+    pred.freq<-sort(x$Predictor.frequency[names(pscore)[1:num]], decreasing=TRUE, na.last = TRUE)
+    piscore<-x$PI.importance
+    vimp.freq<-sort(x$PI.frequency[names(piscore)[1:num]], decreasing=TRUE, na.last = TRUE)
+  }
+  else if (sortby == 'importance'){
+    pscore<-sort(x$Predictor.importance, decreasing=TRUE, na.last = TRUE)
+    pred.freq<-x$Predictor.frequency[names(pscore)[1:num]]
+    piscore<-sort(x$PI.importance, decreasing=TRUE, na.last = TRUE)
+    vimp.freq<-x$PI.frequency[names(piscore)[1:num]]
+  }
+  #MN edits end
+
   p.1st<-paste("Top ", num, " Predictors", sep="")
   pi.1st<-paste("Top ", num, " Interactions", sep="")
   if (x$norm==TRUE)
